==> siggy_0.4.1.tar.gz: siggy-0.4.1/src/summarydata.cpp <==
#include "summarydata.h"

SummaryData::SummaryData(int startYear,
                         int startMonth,
                         int endYear,
                         int endMonth)
{
        _startYear = startYear;
        _startMonth = startMonth;
        _endYear = endYear;
        _endMonth = endMonth;

        _totalBudget = 0;
        _totalExpense = 0;
        _totalSaved = 0;
        _maxExpense = 0;
        _minExpense = INT_MAX;
        _minSaved = INT_MAX;
        _maxSaved = 0;
        _monthCount = 0;
}

SummaryData::~SummaryData()
{
        foreach (Concept *concept, _concepts) {
                delete concept;
        }
}

int SummaryData::startYear()
{
        return _startYear;
}

int SummaryData::startMonth()
{
        return _startMonth;
}

int SummaryData::endYear()
{
        return _endYear;
}

int SummaryData::endMonth()
{
        return _endMonth;
}

void SummaryData::addMonthData(double budget, double expense)
{
        _totalBudget += budget;
        _totalExpense +=  expense;
        int saved = budget - expense;
        _totalSaved += saved;
        _monthCount ++;

        if (expense > _maxExpense) {
                _maxExpense = expense;
        }

        if (expense < _minExpense) {
                _minExpense = expense;
        }

        if (saved > _maxSaved) {
                _maxSaved = saved;
        }

        if (saved < _minSaved) {
                _minSaved = saved;
        }
}

double SummaryData::totalBudget()
{
        return _totalBudget;
}

double SummaryData::totalExpense()
{
        return _totalExpense;
}

double SummaryData::totalSaved()
{
        return _totalSaved;
}

double SummaryData::maxExpense()
{
        return _maxExpense;
}

double SummaryData::minExpense()
{
        return _minExpense;
}

double SummaryData::maxSaved()
{
        return _maxSaved;
}

double SummaryData::minSaved()
{
        return _minSaved;
}

double SummaryData::averageExpense()
{
        return _totalExpense/_monthCount;
}

double SummaryData::averageSaved()
{
        return _totalSaved/_monthCount;
}

void SummaryData::addConcept(Concept *c)
{
        _concepts.append(c);
}

const QList<Concept*>& SummaryData::concepts()
{
        return _concepts;
}

==> siggy_0.5.tar.gz: siggy-0.5/src/summarydata.cpp <==
#include "summarydata.h"
#include <climits>

SummaryData::SummaryData(int startYear,
                         int startMonth,
                         int endYear,
                         int endMonth,
                         QObject *parent)
        : ExpensesGraphModel(parent)
{
        _startYear = startYear;
        _startMonth = startMonth;
        _endYear = endYear;
        _endMonth = endMonth;

        _totalBudget = 0;
        _totalExpense = 0;
        _totalSaved = 0;
        _maxExpense = 0;
        _maxBudget = 0;
        _minExpense = INT_MAX;
        _minSaved = INT_MAX;
        _maxSaved = 0;
        _monthCount = 0;
}

SummaryData::~SummaryData()
{
        foreach (Concept *concept, _concepts) {
                delete concept;
        }
}

int SummaryData::startYear()
{
        return _startYear;
}

int SummaryData::startMonth()
{
        return _startMonth;
}

int SummaryData::endYear()
{
        return _endYear;
}

int SummaryData::endMonth()
{
        return _endMonth;
}

void SummaryData::addMonthData(double budget, double expense)
{
        _totalBudget += budget;
        _totalExpense +=  expense;
        int saved = budget - expense;
        _totalSaved += saved;

        _values.append(expense);
        _references.append(budget);

        if (budget > _maxBudget) {
                _maxBudget = budget;
        }

        if (expense > _maxExpense) {
                _maxExpense = expense;
        }

        if (expense < _minExpense) {
                _minExpense = expense;
        }

        if (saved > _maxSaved) {
                _maxSaved = saved;
        }

        if (saved < _minSaved) {
                _minSaved = saved;
        }
        _monthCount ++;
}

double SummaryData::totalBudget()
{
        return _totalBudget;
}

double SummaryData::totalExpense()
{
        return _totalExpense;
}

double SummaryData::totalSaved()
{
        return _totalSaved;
}

double SummaryData::maxExpense()
{
        return _maxExpense;
}

double SummaryData::maxBudget()
{
        return _maxBudget;
}

double SummaryData::minExpense()
{
        return _minExpense;
}

double SummaryData::maxSaved()
{
        return _maxSaved;
}

double SummaryData::minSaved()
{
        return _minSaved;
}

double SummaryData::averageExpense()
{
        return _totalExpense/_monthCount;
}

double SummaryData::averageSaved()
{
        return _totalSaved/_monthCount;
}

void SummaryData::addConcept(Concept *c)
{
        _concepts.append(c);
}

const QList<Concept*>& SummaryData::concepts()
{
        return _concepts;
}

double SummaryData::budget()
{
        return _totalBudget;
}

bool SummaryData::isCurrent()
{
        return false;
}

int SummaryData::xDivisions()
{
        return _monthCount;
}

double SummaryData::value(int index)
{
        return _values.value(index);
}

int SummaryData::label(int index)
{
    int m = (index + _startMonth) % 12;
    if (m == 0)
        m = 12;

    return m;
}

double SummaryData::reference(int i)
{
        return _references.value(i);
}
